/* eel-i18n.h: I18n stuff for Eel.

   Copyright (C) 2002 MandrakeSoft

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation, Inc.,; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor
   Boston, MA 02110-1335 USA.

   Authors: Frederic Crozat <fcrozat@mandrakesoft.com>
*/

#ifndef EEL_I18N_H
#define EEL_I18N_H

#include <glib/gi18n.h>

#endif /* EEL_I18N_H */
